# -*- coding: utf-8 -*-
from datetime import datetime

extensions = [
    'm2r',
    'sphinx_rtd_theme',
]

source_suffix = '.rst'

master_doc = 'index'

# General information about the project.
project = u'navit'
year = datetime.now().year
author = u'The Navit Team'



#! /usr/bin/python
import dbus
bus = dbus.SessionBus()
conn = bus.get_object('org.navit_project.navit',
                       '/org/navit_project/navit')
iface = dbus.Interface(conn, dbus_interface='org.navit_project.navit')
_iter=iface.attr_iter()
navit=bus.get_object('org.navit_project.navit', conn.get_attr_wi("navit",_iter)[1])
iface.attr_iter_destroy(_iter)
navit_iface = dbus.Interface(navit, dbus_interface='org.navit_project.navit.navit')
navit_iface.set_center((1,0x138a4a,0x5d773f))



import glob
import dbus
from dbus import glib
import gobject
import sys
import os
import time
from subprocess import call
from junit_xml import TestSuite, TestCase


gobject.threads_init()

glib.init_threads()

bus = dbus.SessionBus()

navit_object = bus.get_object("org.navit_project.navit", # Connection name
                               "/org/navit_project/navit/default_navit" ) # Object's path

iface = dbus.Interface(navit_object, dbus_interface="org.navit_project.navit.navit")
junit_directory=sys.argv[1]
if not os.path.exists(junit_directory):
    os.makedirs(junit_directory)

tests=[]
start_time = time.time()
test_cases = TestCase("zoom (factor) expected 512", '', time.time() - start_time, '', '')
iface.zoom(-2)
zoom=iface.get_attr("zoom")[1]
if zoom !=512 :
   test_cases.add_failure_info('zoom level mismatch. Got '+str(zoom)+', expected 512')
tests.append(test_cases)

test_cases = TestCase("zoom (factor) expected 1024", '', time.time() - start_time, '', '')
iface.zoom(-2)
zoom=iface.get_attr("zoom")[1]
if zoom !=1024 :
   test_cases.add_failure_info('zoom level mismatch. Got '+str(zoom)+', expected 1024')
tests.append(test_cases)

test_cases = TestCase("zoom via set_attr expected 512", '', time.time() - start_time, '', '')
iface.set_attr("zoom", 512)
zoom=iface.get_attr("zoom")[1]
if zoom !=512 :
   test_cases.add_failure_info('zoom level mismatch. Got '+str(zoom)+', expected 512')
tests.append(test_cases)

ts = [TestSuite("Navit dbus tests", tests)]

with open(junit_directory+'dbus.xml', 'w+') as f:
    TestSuite.to_file(f, ts, prettyprint=False)



import navit
navit.config_load("navit.xml.local")
pos=navit.pcoord("5023.7493 N 00730.2898 E",1)
dest=navit.pcoord("5023.6604 N 00729.8500 E",1)
inst=navit.config().navit()
inst.set_position(pos)
inst.set_destination(dest,"Test")
inst.set_center(pos)



#!/usr/bin/python
#
# Copyright 2014 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the 'License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Uploads an apk to the beta track."""

import argparse
import sys
from apiclient import sample_tools
from oauth2client import client

TRACK = 'beta'  # Can be 'alpha', beta', 'production' or 'rollout'

# Declare command-line flags.
argparser = argparse.ArgumentParser(add_help=False)
argparser.add_argument('package_name',
                       help='The package name. Example: com.android.sample')
argparser.add_argument('apk_file',
                       nargs='?',
                       default='test.apk',
                       help='The path to the APK file to upload.')


def main(argv):
  # Authenticate and construct service.
  service, flags = sample_tools.init(
      argv,
      'androidpublisher',
      'v2',
      __doc__,
      __file__, parents=[argparser],
      scope='https://www.googleapis.com/auth/androidpublisher')

  # Process flags and read their values.
  package_name = flags.package_name
  apk_file = flags.apk_file

  try:
    edit_request = service.edits().insert(body={}, packageName=package_name)
    result = edit_request.execute()
    edit_id = result['id']

    apk_response = service.edits().apks().upload(
        editId=edit_id,
        packageName=package_name,
        media_body=apk_file).execute()

    print 'Version code %d has been uploaded' % apk_response['versionCode']

    track_response = service.edits().tracks().update(
        editId=edit_id,
        track=TRACK,
        packageName=package_name,
        body={u'versionCodes': [apk_response['versionCode']]}).execute()

    print 'Track %s is set for version code(s) %s' % (
        track_response['track'], str(track_response['versionCodes']))

    commit_request = service.edits().commit(
        editId=edit_id, packageName=package_name).execute()

    print 'Edit "%s" has been committed' % (commit_request['id'])

  except client.AccessTokenRefreshError:
    print ('The credentials have been revoked or expired, please re-run the '
           'application to re-authorize')

if __name__ == '__main__':
  main(sys.argv)



#!/usr/bin/python
import json
import argparse
parser = argparse.ArgumentParser()

parser.add_argument("-csv" , help="Output all files opmitted as a csv file, saperated by comma or if set by opmitted seperator", action="store_true")
parser.add_argument("-csv-seperator", help="Set the seperator used by csv output", default=",")
parser.add_argument("files", type=argparse.FileType('r'), nargs='+')

args=parser.parse_args()

for f in args.files:
	content=f.read()
	json_obj = json.loads(content)
	minx=999999
	maxx=-999999
	miny=999999
	maxy=-999999
	if json_obj['geometry']['type'] == "Polygon":
		for region in json_obj['geometry']['coordinates'][0]:
			minx=min(minx,region[0])
			maxx=max(maxx,region[0])
			miny=min(miny,region[1])
			maxy=max(maxy,region[1])
	elif json_obj['geometry']['type'] == "MultiPolygon":
		for sub in json_obj['geometry']['coordinates']:
			for region in sub[0]:
				minx=min(minx,region[0])
				maxx=max(maxx,region[0])
				miny=min(miny,region[1])
				maxy=max(maxy,region[1])
	if args.csv:
		print(f.name+args.csv_seperator+str(minx)+args.csv_seperator+str(miny)+args.csv_seperator+str(maxx)+args.csv_seperator+str(maxy))
	else:
		print(f.name+": "+str(minx)+" "+str(miny)+" x "+str(maxx)+" "+str(maxy))
